<?php
/** 
*
* common [Turkish]
*
* @package language
* @version $Id: common.php,v 1.183 2007/06/09 11:10:24 acydburn Exp $ 
* @copyright (c) 2005 phpBB Group 
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
   exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine
// 
// Some characters you may want to copy&paste: 
// ’ » “ ” … 
// 

$lang = array_merge($lang, array(
	'TRANSLATION_INFO'	=> '<br />Türkçe çeviri: <a href="http://www.phpbbturkey.com/">phpBB Türkiye</a>',
	'DIRECTION'		=> 'ltr',
	'DATE_FORMAT'		=> '|d M Y|',	// 01 Jan 2007 (with Relative days enabled)
	'USER_LANG'			=> 'tr',

	'1_DAY'					=> '1 Gün',
	'1_MONTH'				=> '1 Ay',
	'1_YEAR'				=> '1 Yıl',
	'2_WEEKS'				=> '2 Hafta',
	'3_MONTHS'				=> '3 Ay',
	'6_MONTHS'				=> '6 Ay',
	'7_DAYS'				=> '7 Gün',

	'ACCOUNT_ALREADY_ACTIVATED'		=> 'Hesabınız zaten aktif edildi.',
	'ACCOUNT_DEACTIVATED'			=> 'Hesabınız elle deaktif edildi ve sadece bir yönetici tarafından yeniden aktif edilebilir.',
	'ACCOUNT_NOT_ACTIVATED'			=> 'Hesabınız şu an aktif değil.',
	'ACP'					=> 'Yönetim Kontrol Paneli',
	'ACTIVE'				=> 'aktif',
	'ACTIVE_ERROR'				=> 'Belirtilen kullanıcı adı şu anda aktif değil. Eğer hesabınızı aktifleştirmeyle ilgili probleminiz varsa, lütfen bir mesaj panosu yöneticisi ile iletişime geçin.',
	'ADMINISTRATOR'				=> 'Yönetici',
	'ADMINISTRATORS'			=> 'Yöneticiler',
	'AGE'							=> 'Yaş',
	'AIM'							=> 'AIM',
	'ALLOWED'				=> 'İzinli',
	'ALL_FILES'						=> 'Tüm dosyalar',
	'ALL_FORUMS'				=> 'Tüm forumlar',
	'ALL_MESSAGES'				=> 'Tüm mesajlar',
	'ALL_POSTS'				=> 'Tüm mesajlar',
	'ALL_TIMES'				=> 'Tüm zamanlar %1$s %2$s',
	'ALL_TOPICS'				=> 'Tüm Başlıklar',
	'AND'					=> 'Ve',
	'ARE_WATCHING_FORUM'			=> 'Bu foruma yeni mesajlardan haberdar edilmek için abone oldunuz.',
	'ARE_WATCHING_TOPIC'			=> 'Bu başlığa yeni mesajlardan haberdar edilmek için abone oldunuz.',
	'ASCENDING'				=> 'Artan',
	'ATTACHMENTS'				=> 'Eklentiler',
	'ATTACHED_IMAGE_NOT_IMAGE'		=> 'Eklemeye çalıştığınız resim dosyası geçersiz.',
	'AUTHOR'				=> 'Yazar',
	'AUTH_NO_PROFILE_CREATED'		=> 'Bir kullanıcının profili oluşturulurken başarısız olundu.',
	'AVATAR_DISALLOWED_CONTENT'      => 'Yükleme kabul edilmedi. Çünkü yüklenen dosya olası bir saldırı taşıyıcısı olarak belirlendi.',
	'AVATAR_DISALLOWED_EXTENSION'		=> 'Bu dosya görüntülenemeyecektir, çünkü %s isimli uzantıya izin verilmiyor.',
	'AVATAR_EMPTY_REMOTE_DATA'		=> 'Belirtilen avatar yüklenemedi, çünkü gösterilen uzak veri geçersiz ya da bozuk.',
	'AVATAR_EMPTY_FILEUPLOAD'		=> 'Yüklenen avatar dosyası boş.',
	'AVATAR_INVALID_FILENAME'		=> '%s geçersiz dosya adı.',
	'AVATAR_NOT_UPLOADED'			=> 'Avatar gönderilemedi.',
	'AVATAR_NO_SIZE'				=> 'Bağlantı verilen avatarın genişlik veya yüksekliği belirlenemedi, lütfen onları elle girin.',
	'AVATAR_PARTIAL_UPLOAD'			=> 'Belirtilen dosyanın sadece bir kısmı yüklendi.',
	'AVATAR_PHP_SIZE_NA'			=> 'Avatar dosya boyutu çok büyük.<br />php.ini dosyasında ayarlanmış izin verilen en yüksek dosya boyutu belirlenemiyor.',
	'AVATAR_PHP_SIZE_OVERRUN'		=> 'Avatar dosya boyutu çok büyük. İzin verilen en yüksek yükleme boyutu %1$d %2$s.<br />Not: Bu ayar php.ini dosyasında belirlenmiştir ve üzerine yazılamaz.',
	'AVATAR_REMOTE_UPLOAD_TIMEOUT'		=> 'Belirtilen avatar yüklenemedi, çünkü istek zaman aşımına uğradı.',
	'AVATAR_URL_INVALID'			=> 'Belirtilen URL hatalı.',
	'AVATAR_URL_NOT_FOUND'			=> 'Belirtilen dosya bulunamıyor.',
	'AVATAR_WRONG_FILESIZE'			=> 'Avatar’ın dosya boyutu 0 ve %1$d %2$s arasında olmalıdır.',
	'AVATAR_WRONG_SIZE'			=> 'Eklenen avatar %5$d piksel genişliğinde ve %6$d piksel yüksekliğinde. Avatarlar en az %1$d piksel genişliğinde ve %2$d piksel yüksekliğinde olmalıdır, fakat %3$d piksel genişliğinden ve %4$d piksel yüksekliğinden fazla olamaz.',

	'BACK_TO_TOP'			=> 'Başa Dön',
	'BACK_TO_PREV'			=> 'Önceki sayfaya dön',
	'BAN_TRIGGERED_BY_EMAIL'=> 'E-posta adresiniz üzerine bir yasaklama yapılmıştır.',
	'BAN_TRIGGERED_BY_IP'	=> 'IP adresiniz üzerine bir yasaklama yapılmıştır.',
	'BAN_TRIGGERED_BY_USER'	=> 'Kullanıcı adınız üzerine bir yasaklama yapılmıştır.',
	'BBCODE_GUIDE'			=> 'BBCode kılavuzu',
	'BCC'					=> 'BCC',
	'BIRTHDAYS'				=> 'Doğum günleri',
	'BOARD_BAN_PERM'		=> 'Bu mesaj panosundan <strong>süresiz</strong> yasaklandınız.<br /><br />Daha fazla bilgi için lütfen %2$sMesaj Panosu Yöneticisi%3$s ile iletişime geçin.',
	'BOARD_BAN_REASON'		=> 'Yasaklama için belirlenen sebep: <strong>%s</strong>',
	'BOARD_BAN_TIME'		=> '<strong>%1$s</strong> zamanına kadar bu mesaj panosundan yasaklandınız.<br /><br />Daha fazla bilgi için lütfen %2$sMesaj Panosu Yöneticisi%3$s ile iletişime geçin.',
	'BOARD_DISABLE'			=> 'Üzgünüz fakat bu mesaj panosu şimdilik kullanılamıyor.',
	'BOARD_DISABLED'			=> 'Bu mesaj panosu şu an kapalı durumda.',
	'BOARD_UNAVAILABLE'		=> 'Üzgünüz fakat bu mesaj panosu geçici olarak kullanılamıyor, lütfen bir kaç dakika sonra tekrar deneyin.',
	'BROWSING_FORUM'      => 'Bu forumu gezen kullanıcılar: %1$s',
	'BROWSING_FORUM_GUEST'	=> 'Bu forumu gezen kullanıcılar: %1$s ve %2$d misafir',
	'BROWSING_FORUM_GUESTS'	=> 'Bu forumu gezen kullanıcılar: %1$s ve %2$d misafir',
	'BYTES'					=> 'Byte',

	'CANCEL'				=> 'İptal',
	'CHANGE'				=> 'Değiştir',
	'CHANGE_FONT_SIZE'		=> 'Font boyutunu değiştir',
 	'CHANGING_PREFERENCES'	=> 'Mesaj panosu tercihleri değiştiriliyor',
 	'CHANGING_PROFILE'		=> 'Profil ayarları değiştiriliyor',
	'CLICK_VIEW_PRIVMSG'	=> '%sGelen kutusuna git%s',
	'COLLAPSE_VIEW'			=> 'Açılır kapanır görüntüleme',
	'CLOSE_WINDOW'			=> 'Pencereyi kapat',
	'COLOUR_SWATCH'			=> 'Renk kuşağı',
	'COMMA_SEPARATOR'		=> ', ',	// Used in pagination of ACP & prosilver, use localised comma if appropriate, eg: Ideographic or Arabic
	'CONFIRM'				=> 'Onay',
	'CONFIRM_CODE'			=> 'Onay kodu',
	'CONFIRM_CODE_EXPLAIN'	=> 'Görünen kodu tam olarak girin. Tüm harfleri büyük ya da küçük olarak yazabilirsiniz.',
	'CONFIRM_CODE_WRONG'	=> 'Girdiğiniz onay kodu hatalı.',
	'CONFIRM_OPERATION'		=> 'Bu işlemi gerçekleştirmek istediğinize emin misiniz?',
	'CONGRATULATIONS'		=> 'Tebrikler',
	'CONNECTION_FAILED'		=> 'Bağlantı hatası.',
	'CONNECTION_SUCCESS'	=> 'Başarıyla bağlanıldı!',
	'COOKIES_DELETED'		=> 'Tüm mesaj panosu çerezleri başarıyla silindi.',
	'CURRENT_TIME'			=> 'Zaman: %s',

	'DAY'					=> 'Gün',
	'DAYS'					=> 'Gün',
	'DELETE'				=> 'Sil',
	'DELETE_ALL'			=> 'Tümünü sil',
	'DELETE_COOKIES'		=> 'Tüm mesaj panosu çerezlerini sil',
	'DELETE_MARKED'			=> 'İşaretlileri Sil',
	'DELETE_POST'			=> 'Mesajı sil',
	'DELIMITER'				=> 'Sınırlayıcı',
	'DESCENDING'			=> 'Azalan',
	'DISABLED'				=> 'Kapalı',
	'DISPLAY'				=> 'Göster',
	'DISPLAY_GUESTS'		=> 'Misafirleri göster',
	'DISPLAY_MESSAGES'		=> 'Eskiden itibaren mesajları göster',
	'DISPLAY_POSTS'			=> 'Eskiden itibaren mesajları göster',
	'DISPLAY_TOPICS'		=> 'Eskiden itibaren başlıkları göster',
	'DOWNLOADED'			=> 'İndirilme',
	'DOWNLOADING_FILE'		=> 'Dosya indiriliyor',
	'DOWNLOAD_COUNT'		=> '%d kere indirildi',
	'DOWNLOAD_COUNTS'		=> '%d kere indirildi',
	'DOWNLOAD_COUNT_NONE'	=> 'Hiç indirilmedi',
 	'VIEWED_COUNT'			=> '%d kere görüntülendi',
 	'VIEWED_COUNTS'			=> '%d kere görüntülendi',
 	'VIEWED_COUNT_NONE'		=> 'Hiç görüntülenmedi',

	'EDIT_POST'			=> 'Mesajı düzenle',
	'EMAIL'				=> 'E-posta', // Short form for EMAIL_ADDRESS
	'EMAIL_ADDRESS'			=> 'E-posta adresi',
	'EMAIL_INVALID_EMAIL'				=> 'Girdiğiniz e-posta adresi geçersiz.',
	'EMAIL_SMTP_ERROR_RESPONSE'			=> 'E-posta gönderilirken iç sunucu problemi oluştu <strong>Satır %1$s</strong>. Yanıt: %2$s.',
	'EMPTY_SUBJECT'			=> 'Yeni bir başlık göndereceğiniz zaman bir konu belirlemelisiniz.',
	'EMPTY_MESSAGE_SUBJECT'  => 'Yeni bir mesaj oluşturacağınız zaman bir konu belirlemelisiniz.',
	'ENABLED'			=> 'Açık',
	'ENCLOSURE'			=> 'Çevir',
	'ENTER_USERNAME'					=> 'Kullanıcı adı girin',
	'ERR_CHANGING_DIRECTORY'			=> 'Dizin değiştirilemiyor.',
	'ERR_CONNECTING_SERVER'				=> 'Sunucuya bağlanırken hata oluştu.',
	'ERR_JAB_AUTH'                  => 'Jabber sunucusunda erişim izni verilmedi.',
	'ERR_JAB_CONNECT'               => 'Jabber sunucusuna bağlanılamadı.',
	'ERR_UNABLE_TO_LOGIN'				=> 'Belirtilen kullanıcı adı veya şifre hatalı.',
	'ERR_UNWATCHING'               => 'Abonelik iptal edilmeye çalışılırken bir hata oluştu.',
	'ERR_WATCHING'                  => 'Abone olmaya çalışılırken bir hata oluştu.',
	'ERR_WRONG_PATH_TO_PHPBB'			=> 'Belirtilen phpBB dosya yolu geçersiz görünüyor.',
	'EXPAND_VIEW'						=> 'Geniş görünüm',
	'EXTENSION'							=> 'Uzantı',
	'EXTENSION_DISABLED_AFTER_POSTING'	=> '<strong>%s</strong> uzantısı deaktif edildi ve görüntülenemiyor.',

	'FAQ'					=> 'SSS',
	'FAQ_EXPLAIN'			=> 'Sıkça Sorulan Sorular',
	'FILENAME'				=> 'Dosya adı',
	'FILESIZE'				=> 'Dosya boyutu',
	'FILEDATE'				=> 'Dosya tarihi',
	'FILE_COMMENT'			=> 'Dosya yorumu',
	'FILE_NOT_FOUND'		=> 'İstenilen dosya bulunamadı.',
	'FIND_USERNAME'			=> 'Bir üye bul',
	'FOLDER'				=> 'Klasör',
	'FORGOT_PASS'			=> 'Şifremi unuttum',
	'FORM_INVALID'         => 'Gönderilen form geçersiz. Tekrar göndermeyi deneyin.',
	'FORUM'					=> 'Forum',
	'FORUMS'				=> 'Forumlar',
	'FORUMS_MARKED'			=> 'Forumlar okunmuş sayıldı.',
	'FORUM_CAT'				=> 'Forum kategorisi',
	'FORUM_INDEX'			=> 'Forum ana sayfa',
	'FORUM_LINK'			=> 'Forum bağlantısı',
	'FORUM_LOCATION'		=> 'Forum yeri',
	'FORUM_LOCKED'			=> 'Forum kilitlendi',
	'FORUM_RULES'			=> 'Forum kuralları',
	'FORUM_RULES_LINK'		=> 'Forum kurallarını görüntülemek için lütfen buraya tıklayın',
	'FROM'					=> 'kısım',
	'FSOCK_DISABLED'		=> 'İşlem tamamlanamadı, çünkü <var>fsockopen</var> fonksiyonu kapatıldı ya da mevcut sunucu sorgusu bulunamadı.',
	'FSOCK_TIMEOUT'			=> 'Ağ akışı okunurken bir zaman aşımı oluştu.',

	'FTP_FSOCK_HOST'					=> 'FTP sunucusu',
	'FTP_FSOCK_HOST_EXPLAIN'			=> 'Sitenize bağlanmak için kullandığınız FTP sunucusu.',
	'FTP_FSOCK_PASSWORD'				=> 'FTP şifresi',
	'FTP_FSOCK_PASSWORD_EXPLAIN'		=> 'FTP kullanıcı adınız için şifre.',
	'FTP_FSOCK_PORT'					=> 'FTP portu',
	'FTP_FSOCK_PORT_EXPLAIN'			=> 'Sunucunuza bağlanmak için kullandığınız port.',
	'FTP_FSOCK_ROOT_PATH'				=> 'phpBB yolu',
	'FTP_FSOCK_ROOT_PATH_EXPLAIN'		=> 'phpBB mesaj panonuza ana dizinden gelen dosya yolu.',
	'FTP_FSOCK_TIMEOUT'				=> 'FTP zaman aşımı',
	'FTP_FSOCK_TIMEOUT_EXPLAIN'		=> 'Saniye cinsinden zaman miktarı, sistem sunucunuzdan gelecek bir cevap için bekleyecek.',
	'FTP_FSOCK_USERNAME'				=> 'FTP kullanıcı adı',
	'FTP_FSOCK_USERNAME_EXPLAIN'		=> 'Sunucunuza bağlanırken kullandığınız kullanıcı adı.',

	'FTP_HOST'					=> 'FTP sunucusu',
	'FTP_HOST_EXPLAIN'			=> 'Sitenize bağlanmak için kullandığınız FTP sunucusu.',
	'FTP_PASSWORD'				=> 'FTP şifresi',
	'FTP_PASSWORD_EXPLAIN'		=> 'FTP kullanıcı adınız için şifre.',
	'FTP_PORT'					=> 'FTP portu',
	'FTP_PORT_EXPLAIN'			=> 'Sunucunuza bağlanmak için kullandığınız port.',
	'FTP_ROOT_PATH'				=> 'phpBB yolu',
	'FTP_ROOT_PATH_EXPLAIN'		=> 'phpBB mesaj panonuza ana dizinden gelen dosya yolu.',
	'FTP_TIMEOUT'				=> 'FTP zaman aşımı',
	'FTP_TIMEOUT_EXPLAIN'		=> 'Saniye cinsinden zaman miktarı, sistem sunucunuzdan gelecek bir cevap için bekleyecek.',
	'FTP_USERNAME'				=> 'FTP kullanıcı adı',
	'FTP_USERNAME_EXPLAIN'		=> 'Sunucunuza bağlanırken kullandığınız kullanıcı adı.',

	'GENERAL_ERROR'				=> 'Genel Hata',
	'GB'                  => 'GB',
	'GIB'                  => 'GiB',
	'GO'						=> 'Git',
	'GOTO_PAGE'					=> 'Sayfaya git',
	'GROUP'						=> 'Grup',
	'GROUPS'					=> 'Gruplar',
	'GROUP_ERR_TYPE'			=> 'Uygunsuz grup tipi belirtildi.',
	'GROUP_ERR_USERNAME'		=> 'Hiç bir grup adı belirtilmedi.',
	'GROUP_ERR_USER_LONG'		=> 'Grup adı 60 karakteri geçemez. Belirtilen grup adı çok uzun.',
	'GUEST'						=> 'Misafir',
	'GUEST_USERS_ONLINE'		=> '%d misafir kullanıcı çevrimiçi',
	'GUEST_USERS_TOTAL'			=> '%d misafir',
	'GUEST_USERS_ZERO_ONLINE'	=> '0 misafir kullanıcı çevrimiçi',
	'GUEST_USERS_ZERO_TOTAL'	=> '0 misafir',
	'GUEST_USER_ONLINE'			=> '%d misafir kullanıcı çevrimiçi',
	'GUEST_USER_TOTAL'			=> '%d misafir',
	'G_ADMINISTRATORS'			=> 'Yöneticiler',
	'G_BOTS'					=> 'Botlar',
	'G_GUESTS'					=> 'Misafirler',
	'G_REGISTERED'				=> 'Kayıtlı kullanıcılar',
	'G_REGISTERED_COPPA'		=> 'Kayıtlı COPPA kullanıcıları',
	'G_GLOBAL_MODERATORS'		=> 'Global moderatörler',
	'G_NEWLY_REGISTERED'		=> 'Yeni kayıtlı kullanıcılar',

	'HIDDEN_USERS_ONLINE'		=> '%d gizli kullanıcı çevrimiçi',
	'HIDDEN_USERS_TOTAL'		=> '%d gizli',
	'HIDDEN_USERS_TOTAL_AND'      => '%d gizli ve ',
	'HIDDEN_USERS_ZERO_ONLINE'	=> '0 gizli kullanıcı çevrimiçi',
	'HIDDEN_USERS_ZERO_TOTAL'	=> '0 gizli',
	'HIDDEN_USERS_ZERO_TOTAL_AND'   => '0 gizli ve ',
	'HIDDEN_USER_ONLINE'		=> '%d gizli kullanıcı çevrimiçi',
	'HIDDEN_USER_TOTAL'			=> '%d gizli',
	'HIDDEN_USER_TOTAL_AND'         => '%d gizli ve ',
	'HIDE_GUESTS'				=> 'Misafirleri gizle',
	'HIDE_ME'					=> 'Bu oturumda çevrimiçi olduğumu gizle',
	'HOURS'						=> 'Saat',
	'HOME'						=> 'Ana sayfa',

	'ICQ'						=> 'ICQ',
	'ICQ_STATUS'				=> 'ICQ durumu',
	'IF'						=> 'Eğer',
	'IMAGE'						=> 'Resim',
	'IMAGE_FILETYPE_INVALID'	=> 'Mimetype %s için %d resim dosya tipi desteklenmiyor.',
	'IMAGE_FILETYPE_MISMATCH'	=> 'Resim dosya tipi uyumsuz: tahmin edilen uzantı %1$s fakat %2$s uzantısı verildi.',
	'IN'						=> 'forum',
	'INDEX'					=> 'Ana sayfa',
	'INFORMATION'			=> 'Bilgi',
	'INTERESTS'				=> 'İlgi alanları',
	'INVALID_DIGEST_CHALLENGE'	=> 'Geçersiz derleme sorgusu.',
	'INVALID_EMAIL_LOG'		=> '<strong>%s</strong> hatalı bir e-posta adresi olabilir?',
	'IP'					=> 'IP',
	'IP_BLACKLISTED'			=> 'IP adresiniz %1$s engellendi çünkü kara listede. Detaylar için lütfen bakınız: <a href="%2$s">%2$s</a>.',

	'JABBER'				=> 'Jabber',
	'JOINED'				=> 'Kayıt',
	'JUMP_PAGE'				=> 'Geçiş yapmak istediğiniz sayfa numarasını girin',
	'JUMP_TO'				=> 'Geçiş yap',
	'JUMP_TO_PAGE'			=> 'Sayfaya geçiş yapmak için tıklayın…',

	'KB'				=> 'KB',
	'KIB'               => 'KiB',

	'LAST_POST'				=> 'Son mesaj',
	'LAST_UPDATED'			=> 'Son güncelleme',
	'LAST_VISIT'			=> 'Son ziyaret',
	'LDAP_NO_LDAP_EXTENSION'	=> 'LDAP uzantısı mevcut değil.',
	'LDAP_NO_SERVER_CONNECTION'	=> 'LDAP sunucusuna bağlanılamıyor.',
   	'LDAP_SEARCH_FAILED'            => 'LDAP dizini aranırken bir hata oluştu.',	
	'LEGEND'				=> 'Yetkiler',
	'LOCATION'				=> 'Konum',
	'LOCK_POST'				=> 'Mesajı kilitle',
	'LOCK_POST_EXPLAIN'		=> 'Düzenleme engellenecektir',
	'LOCK_TOPIC'			=> 'Başlığı kilitle',
	'LOGIN'					=> 'Giriş',
	'LOGIN_CHECK_PM'		=> 'Özel mesajlarınızı kontrol etmek için giriş yapın.',
	'LOGIN_CONFIRMATION'	=> 'Giriş doğrulaması',
	'LOGIN_CONFIRM_EXPLAIN'	=> 'Bu mesaj panosu, hesaplara yapılan girişimleri engellemek için en fazla yapılabilecek hatalı giriş sayısı aşıldığında onay kodu girmenizi gerekli tutuyor. Kodu alttaki resmin içerisinde görebilirsiniz. Eğer kodu göremiyor veya okuyamıyorsanız lütfen %sMesaj Panosu Yöneticisi%s ile iletişime geçin.', // unused
	'LOGIN_ERROR_ATTEMPTS'	=> 'En fazla izin verilen giriş deneme sayısını aştınız. Kullanıcı adı ve şifrenizle beraber ayrıca alttaki CAPTCHA’yı da çözmelisiniz.',
	'LOGIN_ERROR_EXTERNAL_AUTH_APACHE'	=> 'Apache tarafından doğruluğunuz kanıtlanmadı.',
	'LOGIN_ERROR_PASSWORD'	=> 'Hatalı şifre belirttiniz. Lütfen şifrenizi kontrol edip tekrar deneyin. Eğer problem devam ederse lütfen %sMesaj Panosu Yöneticisi%s ile iletişime geçin.',
	'LOGIN_ERROR_PASSWORD_CONVERT'		=> 'Bu mesaj panosunun yazılımı güncellendiği zaman şifrenizi dönüştürmek mümkün olmadı. Lütfen kendinize %syeni bir şifre isteyin%s. Eğer problemlerle karşılaşmaya devam ederseniz lütfen %sMesaj Panosu Yöneticisi%s ile iletişime geçin.',
	'LOGIN_ERROR_USERNAME'	=> 'Hatalı kullanıcı adı belirttiniz. Lütfen kullanıcı adınızı kontrol edip tekrar deneyin. Eğer problem devam ederse lütfen %sMesaj Panosu Yöneticisi%s ile iletişime geçin.',
	'LOGIN_FORUM'			=> 'Bu forumu görüntülemek veya mesaj göndermek için bir şifre girmelisiniz.',
	'LOGIN_INFO'			=> 'Giriş yapabilmek için kayıt olmalısınız. Kayıt işlemi sadece bir kaç dakikanızı alır, fakat yeteneklerinizi arttırır. Mesaj panosu yöneticisi kayıtlı kullanıcılara ekstra izinler verebilir. Kayıt olmadan önce lütfen kullanım koşullarımızı ve gizlilik ilkelerimizi okuyup kabul ettiğinize emin olun. Lütfen mesaj panosu çevresinde mevcut herhangi bir forum kuralı varsa bu kuralları da okuduğunuza emin olun.',	
	'LOGIN_VIEWFORUM'		=> 'Mesaj panosu, bu forumu görüntülemek için kayıt olmanızı ve giriş yapmanızı gerekli tutuyor.',
	'LOGIN_EXPLAIN_EDIT'	=> 'Bu forumdaki mesajları değiştirmek için kayıtlı olmalı ve giriş yapmalısınız.',
	'LOGIN_EXPLAIN_VIEWONLINE'			=> 'Çevrimiçi listesini görüntülemek için kayıtlı olmalı ve giriş yapmalısınız.',
	'LOGOUT'				=> 'Çıkış',
	'LOGOUT_USER'			=> 'Çıkış [ %s ]',
	'LOG_ME_IN'				=> 'Her ziyaretimde otomatik giriş yap',

	'MARK'				=> 'İşaretle',
	'MARK_ALL'			=> 'Tümünü işaretle',
	'MARK_FORUMS_READ'	=> 'Forumları okunmuş say',
	'MARK_SUBFORUMS_READ'	=> 'Alt forumları okunmuş say',	
	'MB'				=> 'MB',
	'MIB'               => 'MiB',
	'MCP'				=> 'Moderatör Kontrol Paneli',
	'MEMBERLIST'		=> 'Üyeler',
	'MEMBERLIST_EXPLAIN'	=> 'Üyelerin tam listesini görüntüle',
	'MERGE'					=> 'Birleştir',
 	'MERGE_POSTS'			=> 'Mesajları taşı',
	'MERGE_TOPIC'		=> 'Başlığı birleştir',
	'MESSAGE'			=> 'Mesaj',
	'MESSAGES'			=> 'Mesajlar',
	'MESSAGE_BODY'		=> 'Mesaj gövdesi',
	'MINUTES'			=> 'Dakika',
	'MODERATE'			=> 'Yönet',
	'MODERATOR'			=> 'Moderatör',
	'MODERATORS'		=> 'Moderatörler',
 	'MODULE_NOT_ACCESS'		=> 'Modül erişilebilir değil',
 	'MODULE_NOT_FIND'		=> '%s modülü bulunamıyor',
 	'MODULE_FILE_INCORRECT_CLASS'	=> '%s modül dosyası doğru sınıf içermiyor [%s]',	
	'MONTH'				=> 'Ay',
	'MOVE'				=> 'Taşı',
	'MSNM'					=> 'MSNM/WLM',

	'NA'						=> 'YOK',
	'NEWEST_USER'				=> 'Yeni üyemiz <strong>%s</strong>',
	'NEW_MESSAGE'				=> 'Yeni mesaj',
	'NEW_MESSAGES'				=> 'Yeni mesajlar',
	'NEW_PM'					=> '<strong>%d</strong> yeni mesaj',
	'NEW_PMS'					=> '<strong>%d</strong> yeni mesaj',
	'NEW_POST'					=> 'Yeni mesaj',   // Not used anymore
	'NEW_POSTS'					=> 'Yeni mesaj var',   // Not used anymore
	'NEXT'                  => 'Sonraki',      // Used in pagination
	'NEXT_STEP'               => 'Sonraki',
	'NEVER'						=> 'Hiç',
	'NO'						=> 'Hayır',
	'NOT_ALLOWED_MANAGE_GROUP'	=> 'Bu grubu yönetme izniniz yok.',
	'NOT_AUTHORISED'			=> 'Bu alana erişim yetkiniz yok.',
	'NOT_WATCHING_FORUM'		=> 'Bu forumdaki güncellemelere abone değilsiniz.',
	'NOT_WATCHING_TOPIC'		=> 'Bu başlıktaki güncellemelere abone değilsiniz.',
 	'NOTIFY_ADMIN'				=> 'Lütfen mesaj panosu yöneticisine ya da webmaster’a bildirin.',
 	'NOTIFY_ADMIN_EMAIL'		=> 'Lütfen mesaj panosu yöneticisine ya da webmaster’a bildirin: <a href="mailto:%1$s">%1$s</a>',
	'NO_ACCESS_ATTACHMENT'		=> 'Bu dosyaya erişim izniniz yok.',
	'NO_ACTION'					=> 'Hiç bir eylem belirlenmedi.',
	'NO_ADMINISTRATORS'         => 'Hiç yönetici yok.',
	'NO_AUTH_ADMIN'				=> 'Yönetici izinlerine sahip olmadığınız için Yönetim Kontrol Paneline erişiminize izin verilmiyor.',
	'NO_AUTH_ADMIN_USER_DIFFER'	=> 'Bir başka kullanıcıyı yeniden doğrulama yetkiniz yok.',
	'NO_AUTH_OPERATION'			=> 'Bu işlemi tamamlamak için gerekli izinlere sahip değilsiniz.',	
	'NO_CONNECT_TO_SMTP_HOST'	=> 'Smtp sunucusuna bağlanılamıyor : %1$s : %2$s',
	'NO_BIRTHDAYS'				=> 'Bugün doğum günü olan kimse yok',
	'NO_EMAIL_MESSAGE'			=> 'E-posta mesajı boş.',
	'NO_EMAIL_RESPONSE_CODE'	=> 'Posta sunucusundan yanıt alınamadı.',
	'NO_EMAIL_SUBJECT'			=> 'E-posta konusu belirtilmedi.',
	'NO_FORUM'					=> 'Seçtiğiniz forum bulunmuyor',
	'NO_FORUMS'					=> 'Bu mesaj panosunun hiç forumu yok.',
	'NO_GROUP'					=> 'İstenilen kullanıcı grubu bulunmuyor.',
	'NO_GROUP_MEMBERS'			=> 'Bu grubun şimdilik herhangi bir üyesi yok.',
	'NO_IPS_DEFINED'			=> 'Hiç bir IP adresi veya host adı belirtilmedi',
	'NO_MEMBERS'				=> 'Bu arama kriterine göre hiç bir üye bulunamadı.',
	'NO_MESSAGES'				=> 'Mesaj yok',
	'NO_MODE'					=> 'Hiç bir mod seçilmedi.',
	'NO_MODERATORS'            => 'Hiç moderatör yok.',
	'NO_NEW_MESSAGES'			=> 'Yeni mesaj yok',
	'NO_NEW_PM'					=> '<strong>0</strong> yeni mesaj',
	'NO_NEW_POSTS'				=> 'Yeni mesaj yok',   // Not used anymore
	'NO_ONLINE_USERS'			=> 'Hiç bir kayıtlı kullanıcı yok',
	'NO_POSTS'					=> 'Mesaj yok',
	'NO_POSTS_TIME_FRAME'		=> 'Seçilen zaman çerçevesi için bu başlıkta hiç bir mesaj yok.',
	'NO_FEED_ENABLED'			=> 'Bu mesaj panosunda Özet Akışları mevcut değil.',
	'NO_FEED'					=> 'İstenilen Özet Akışı mevcut değil.',
	'NO_STYLE_DATA'				=> 'Stil verisi alınamıyor',
	'NO_SUBJECT'				=> 'Hiç bir konu belirtilmedi.', // Used for posts having no subject defined but displayed within management pages.
	'NO_SUCH_SEARCH_MODULE'		=> 'Belirtilen arama bulunamıyor.',
	'NO_SUPPORTED_AUTH_METHODS'	=> 'Yetki metotları desteklenmedi.',
	'NO_TOPIC'					=> 'İstenilen başlık mevcut değil.',
	'NO_TOPIC_FORUM'         => 'Başlık veya forum mevcut değil.',
	'NO_TOPICS'					=> 'Bu forumda başlık veya mesaj yok.',
	'NO_TOPICS_TIME_FRAME'		=> 'Seçilen zaman çerçevesi için bu forumda hiç bir başlık yok.',
	'NO_UNREAD_PM'				=> '<strong>0</strong> okunmamış mesaj',
	'NO_UNREAD_POSTS'         => 'Okunmamış mesaj yok',	
	'NO_UPLOAD_FORM_FOUND'		=> 'Yükleme başladı fakat geçerli bir dosya yükleme formu bulunmuyor.',
	'NO_USER'					=> 'İstenilen kullanıcı bulunmuyor.',
	'NO_USERS'					=> 'İstenilen kullanıcılar bulunmuyor',
	'NO_USER_SPECIFIED'			=> 'Hiç bir kullanıcı adı belirtilmedi.',

	// Nullar/Singular/Plural language entry. The key numbers define the number range in which a certain grammatical expression is valid.
	'NUM_POSTS_IN_QUEUE'      => array(
		0         => 'Onay bekleyen hiç bir mesaj yok',      // 0
		1         => '1 mesaj onay bekliyor',      // 1
		2         => '%d mesaj onay bekliyor',      // 2+
	),

	'OCCUPATION'				=> 'Meslek',
	'OFFLINE'					=> 'Çevrimdışı',
	'ONLINE'					=> 'Çevrimiçi',
	'ONLINE_BUDDIES'			=> 'Çevrimiçi arkadaşlar',
	'ONLINE_USERS_TOTAL'		=> 'Toplam <strong>%d</strong> kullanıcı çevrimiçi :: ',
	'ONLINE_USERS_ZERO_TOTAL'	=> 'Toplam <strong>0</strong> kullanıcı çevrimiçi :: ',
	'ONLINE_USER_TOTAL'			=> 'Toplam <strong>%d</strong> kullanıcı çevrimiçi :: ',
	'OPTIONS'					=> 'Seçenekler',

	'PAGE_OF'			=> '<strong>%1$d</strong>. sayfa (Toplam <strong>%2$d</strong> sayfa)',
	'PASSWORD'			=> 'Şifre',
	'PIXEL'					=> 'piksel',
	'PLAY_QUICKTIME_FILE'	=> 'Quicktime dosyasını oynat',
	'PM'				=> 'ÖM',
	'PM_REPORTED'         => 'Bildiriyi görüntülemek için tıklayın',
	'POSTING_MESSAGE'	=> 'Mesajın gönderildiği yer %s',
	'POSTING_PRIVATE_MESSAGE'	=> 'Özel mesaj oluşturuluyor',
	'POST'				=> 'Mesaj',
	'POST_ANNOUNCEMENT'	=> 'Duyuru',
	'POST_STICKY'		=> 'Sabit',
	'POSTED'			=> 'Gönderilme zamanı',
	'POSTED_IN_FORUM'	=> 'forumunda',
	'POSTED_ON_DATE'	=> 'tarih',
	'POSTS'				=> 'Mesajlar',
	'POSTS_UNAPPROVED'	=> 'Bu başlıktaki en az bir mesaj onaylanmadı.',
	'POST_BY_AUTHOR'	=> 'gönderen',
	'POST_BY_FOE'		=> 'Bu mesaj <strong>%1$s</strong> tarafından gönderildi ve bu kullanıcı şu an sizin engellenenler listenizde. Mesajı görüntülemek için %2$sBURAYA%3$s tıklayın.',
	'POST_DAY'			=> 'Ortalama her gün %.2f mesaj',
	'POST_DETAILS'		=> 'Mesaj detayları',
	'POST_NEW_TOPIC'	=> 'Yeni başlık gönder',
	'POST_PCT'			=> 'Tüm mesajların %.2f%%',
	'POST_PCT_ACTIVE'	=> 'Kullanıcı mesajlarının %.2f%%',
	'POST_PCT_ACTIVE_OWN'	=> 'Mesajlarınızın %.2f%%',
	'POST_REPLY'			=> 'Cevap gönder',
	'POST_REPORTED'		=> 'Bildiriyi görüntülemek için tıklayın',
	'POST_SUBJECT'		=> 'Mesaj Başlığı',
	'POST_TIME'			=> 'Mesaj tarihi',
	'POST_TOPIC'			=> 'Yeni bir başlık gönder',
	'POST_UNAPPROVED'	=> 'Bu mesaj onay için bekliyor',
	'POWERED_BY'			=> 'Powered by %s',
	'PREVIEW'			=> 'Önizleme',
	'PREVIOUS'            => 'Önceki',      // Used in pagination
	'PREVIOUS_STEP'         => 'Önceki',
	'PRIVACY'			=> 'Gizlilik ilkeleri',
	'PRIVATE_MESSAGE'	=> 'Özel mesaj',
	'PRIVATE_MESSAGES'	=> 'Özel mesajlar',
	'PRIVATE_MESSAGING'	=> 'Özel mesajlaşma',
	'PROFILE'			=> 'Kullanıcı Kontrol Paneli',
	'RANK'						=> 'Rütbe',

	'READING_FORUM'				=> '%s içerisindeki başlıklar görüntüleniyor',
	'READING_GLOBAL_ANNOUNCE'	=> 'Global duyuru okunuyor',
	'READING_LINK'				=> '%s forum bağlantısı takip ediliyor',
	'READING_TOPIC'				=> '%s içerisindeki başlık okunuyor',
	'READ_PROFILE'				=> 'Profil',
	'REASON'					=> 'Sebep',
	'RECORD_ONLINE_USERS'		=> 'Bugüne kadar en çok <strong>%1$s</strong> kişi %2$s tarihinde çevrimiçi oldu',
	'REDIRECT'					=> 'Yönlendirme',
	'REDIRECTS'					=> 'Toplam yönlendirme',
	'REGISTER'					=> 'Kayıt',
	'REGISTERED_USERS'			=> 'Kayıtlı kullanıcılar:',
	'REG_USERS_ONLINE'			=> '%d kayıtlı kullanıcı ve ',
	'REG_USERS_TOTAL'			=> '%d kayıtlı, ',
	'REG_USERS_TOTAL_AND'      => '%d kayıtlı ve ',
	'REG_USERS_ZERO_ONLINE'		=> '0 kayıtlı kullanıcı ve ',
	'REG_USERS_ZERO_TOTAL'		=> '0 kayıtlı, ',
	'REG_USERS_ZERO_TOTAL_AND'   => '0 kayıtlı ve ',
	'REG_USER_ONLINE'			=> '%d kayıtlı kullanıcı ve ',
	'REG_USER_TOTAL'			=> '%d kayıtlı, ',
	'REG_USER_TOTAL_AND'      => '%d kayıtlı ve ',
	'REMOVE'					=> 'Sil',
	'REMOVE_INSTALL'			=> 'Lütfen mesaj panonuzu kullanmadan önce install klasörünü silin, taşıyın veya yeniden adlandırın. Eğer bu klasör mevcutsa, sadece Yönetim Kontrol Paneline (YKP) erişilebilinecektir.',
	'REPLIES'					=> 'Cevaplar',
	'REPLY_WITH_QUOTE'			=> 'Alıntı ile cevapla',
	'REPLYING_GLOBAL_ANNOUNCE'	=> 'Global duyuru cevaplanıyor',
	'REPLYING_MESSAGE'			=> '%s içerisindeki mesaj cevaplanıyor',
	'REPORT_BY'					=> 'Bildiren',
	'REPORT_POST'				=> 'Bu mesajı bildir',
	'REPORTING_POST'			=> 'Mesaj bildiriliyor',
	'RESEND_ACTIVATION'			=> 'Aktivasyon e-postasını tekrar gönder',
	'RESET'						=> 'Sıfırla',
	'RESTORE_PERMISSIONS'		=> 'İzinleri yenile',
	'RETURN_INDEX'				=> '%sAna sayfaya dön%s',
	'RETURN_FORUM'				=> '%sSon ziyaret edilen foruma dön%s',
	'RETURN_PAGE'				=> '%sÖnceki sayfaya dön%s',
	'RETURN_TOPIC'				=> '%sSon ziyaret edilen başlığa dön%s',
	'RETURN_TO'					=> 'Dön',
	'FEED'						=> 'Besleme',
	'FEED_NEWS'					=> 'Haberler',
	'FEED_TOPICS_ACTIVE'		=> 'Aktif Başlıklar',
	'FEED_TOPICS_NEW'			=> 'Yeni Başlıklar',
	'RULES_ATTACH_CAN'			=> 'Bu foruma eklentiler <strong>gönderebilirsiniz</strong>',
	'RULES_ATTACH_CANNOT'		=> 'Bu foruma eklentiler <strong>gönderemezsiniz</strong>',
	'RULES_DELETE_CAN'			=> 'Bu forumdaki mesajlarınızı <strong>silebilirsiniz</strong>',
	'RULES_DELETE_CANNOT'		=> 'Bu forumdaki mesajlarınızı <strong>silemezsiniz</strong>',
	'RULES_DOWNLOAD_CAN'		=> 'Bu forumdaki eklentileri <strong>indirebilirsiniz</strong>',
	'RULES_DOWNLOAD_CANNOT'		=> 'Bu forumdaki eklentileri <strong>indiremezsiniz</strong>',
	'RULES_EDIT_CAN'			=> 'Bu forumdaki mesajlarınızı <strong>düzenleyebilirsiniz</strong>',
	'RULES_EDIT_CANNOT'			=> 'Bu forumdaki mesajlarınızı <strong>düzenleyemezsiniz</strong>',
	'RULES_LOCK_CAN'			=> 'Bu forumdaki başlıklarınızı <strong>kilitleyebilirsiniz</strong>',
	'RULES_LOCK_CANNOT'			=> 'Bu forumdaki başlıklarınızı <strong>kilitleyemezsiniz</strong>',
	'RULES_POST_CAN'			=> 'Bu foruma yeni başlıklar <strong>gönderebilirsiniz</strong>',
	'RULES_POST_CANNOT'			=> 'Bu foruma yeni başlıklar <strong>gönderemezsiniz</strong>',
	'RULES_REPLY_CAN'			=> 'Bu forumdaki başlıklara cevap <strong>verebilirsiniz</strong>',
	'RULES_REPLY_CANNOT'		=> 'Bu forumdaki başlıklara cevap <strong>veremezsiniz</strong>',
	'RULES_VOTE_CAN'			=> 'Bu forumdaki anketlere oy <strong>verebilirsiniz</strong>',
	'RULES_VOTE_CANNOT'			=> 'Bu forumdaki anketlere oy <strong>veremezsiniz</strong>',

	'SEARCH'					=> 'Ara',
	'SEARCH_MINI'				=> 'Ara…',
	'SEARCH_ADV'				=> 'Gelişmiş arama',
	'SEARCH_ADV_EXPLAIN'		=> 'Gelişmiş arama seçeneklerini görüntüle',
	'SEARCH_KEYWORDS'			=> 'Anahtar kelimeleri ara',
	'SEARCHING_FORUMS'			=> 'Forumlar aranıyor',
	'SEARCH_ACTIVE_TOPICS'		=> 'Aktif başlıklar',
	'SEARCH_FOR'				=> 'Aranacak',
	'SEARCH_FORUM'				=> 'Bu forumda ara…',	
	'SEARCH_NEW'				=> 'Yeni mesajlar',
	'SEARCH_POSTS_BY'			=> 'Şu kullanıcının mesajlarını ara',
	'SEARCH_SELF'				=> 'Kendi mesajlarınız',
	'SEARCH_TOPIC'				=> 'Bu başlıkta ara…',
	'SEARCH_UNANSWERED'			=> 'Cevaplanmamış mesajlar',
	'SEARCH_UNREAD'				=> 'Okunmamış mesajlar',
	'SEARCH_USER_POSTS'			=> 'Kullanıcı’nın mesajlarını ara',	
	'SECONDS'					=> 'Saniye',
	'SELECT'					=> 'Seç',
	'SELECT_ALL_CODE'      => 'Tümünü seç',
	'SELECT_DESTINATION_FORUM'	=> 'Lütfen gidilecek bir forum seçin',
	'SELECT_FORUM'				=> 'Bir forum seçin',
	'SEND_EMAIL'				=> 'E-posta',            // Used for submit buttons
	'SEND_EMAIL_USER'         => 'E-posta',            // Used as: {L_SEND_EMAIL_USER} {USERNAME} -> E-mail UserX
	'SEND_PRIVATE_MESSAGE'		=> 'Özel mesaj gönder',
	'SETTINGS'					=> 'Ayarlar',
	'SIGNATURE'					=> 'İmza',
	'SKIP'						=> 'İçeriğe geç',
	'SMTP_NO_AUTH_SUPPORT'		=> 'SMTP sunucusu yetkisi desteklenmiyor.',
	'SORRY_AUTH_READ'			=> 'Bu forumu okuma yetkiniz yok.',
	'SORRY_AUTH_VIEW_ATTACH'	=> 'Bu eklentiyi indirme yetkiniz yok.',
	'SORT_BY'					=> 'Sırala',
	'SORT_JOINED'				=> 'Kayıt tarihi',
	'SORT_LOCATION'				=> 'Yer',
	'SORT_RANK'					=> 'Rütbe',
	'SORT_POSTS'				=> 'Mesajlar',
	'SORT_TOPIC_TITLE'			=> 'Başlık konusu',
	'SORT_USERNAME'				=> 'Kullanıcı adı',
	'SPLIT_TOPIC'				=> 'Başlığı böl',
	'SQL_ERROR_OCCURRED'		=> 'Bu sayfa açılırken bir sql hatası oluştu. Bu problem devam ederse lütfen %sMesaj Panosu Yöneticisi%s ile iletişime geçin.',
	'STATISTICS'				=> 'İstatistikler',
	'START_WATCHING_FORUM'		=> 'Foruma abone ol',
	'START_WATCHING_TOPIC'		=> 'Başlığa abone ol',
	'STOP_WATCHING_FORUM'		=> 'Foruma abone olmayı bırak',
	'STOP_WATCHING_TOPIC'		=> 'Başlığa abone olmayı bırak',
	'SUBFORUM'					=> 'Alt forum',
	'SUBFORUMS'					=> 'Alt forumlar',
	'SUBJECT'					=> 'Konu',
	'SUBMIT'					=> 'Gönder',
	'TB'				=> 'TB',
	
	'TERMS_USE'			=> 'Kullanım koşulları',
	'TEST_CONNECTION'	=> 'Bağlantı testi',
	'THE_TEAM'			=> 'Takım',
	'TIB'				=> 'TiB',	
	'TIME'				=> 'Zaman',
	
	'TOO_LARGE'                  => 'Girdiğiniz değer çok büyük.',
	'TOO_LARGE_MAX_RECIPIENTS'      => 'Girdiğiniz değer <strong>Her mesajda izin verilen en fazla alıcı sayısı</strong> ayarına göre çok büyük.',
	'TOO_LONG'                  => 'Girdiğiniz değer çok uzun.',
	'TOO_LONG_AIM'					=> 'Girdiğiniz görünen ad çok uzun.',
	'TOO_LONG_CONFIRM_CODE'			=> 'Girdiğiniz onay kodu çok uzun.',
	'TOO_LONG_DATEFORMAT'         => 'Girdiğiniz tarih formatı çok uzun.',
	'TOO_LONG_ICQ'					=> 'Girdiğiniz ICQ numarası çok uzun.',
	'TOO_LONG_INTERESTS'			=> 'Girdiğiniz ilgi alanları çok uzun.',
	'TOO_LONG_JABBER'				=> 'Girdiğiniz Jabber hesap adı çok uzun.',
	'TOO_LONG_LOCATION'				=> 'Girdiğiniz şehir çok uzun.',
	'TOO_LONG_MSN'					=> 'Girdiğiniz MSNM/WLM adı çok uzun.',
	'TOO_LONG_NEW_PASSWORD'			=> 'Girdiğiniz şifre çok uzun.',
	'TOO_LONG_OCCUPATION'			=> 'Girdiğiniz meslek çok uzun.',
	'TOO_LONG_PASSWORD_CONFIRM'		=> 'Girdiğiniz şifre doğrulaması çok uzun.',
	'TOO_LONG_USER_PASSWORD'		=> 'Girdiğiniz şifre çok uzun.',
	'TOO_LONG_USERNAME'				=> 'Girdiğiniz kullanıcı adı çok uzun.',
	'TOO_LONG_EMAIL'				=> 'Girdiğiniz e-posta adresi çok uzun.',
	'TOO_LONG_EMAIL_CONFIRM'		=> 'Girdiğiniz e-posta adresi doğrulaması çok uzun.',
	'TOO_LONG_WEBSITE'				=> 'Girdiğiniz web sitesi adresi çok uzun.',
	'TOO_LONG_YIM'					=> 'Girdiğiniz Yahoo! Messenger adı çok uzun.',

	'TOO_MANY_VOTE_OPTIONS'			=> 'Çok fazla seçenek için oy vermeyi denediniz.',

	'TOO_SHORT'                  => 'Girdiğiniz değer çok kısa.',
	'TOO_SHORT_AIM'					=> 'Girdiğiniz görünen ad çok kısa.',
	'TOO_SHORT_CONFIRM_CODE'			=> 'Girdiğiniz onay kodu çok kısa.',
	'TOO_SHORT_DATEFORMAT'         => 'Girdiğiniz tarih formatı çok kısa.',
	'TOO_SHORT_ICQ'					=> 'Girdiğiniz ICQ numarası çok kısa.',
	'TOO_SHORT_INTERESTS'			=> 'Girdiğiniz ilgi alanları çok kısa.',
	'TOO_SHORT_JABBER'				=> 'Girdiğiniz Jabber hesap adı çok kısa.',
	'TOO_SHORT_LOCATION'				=> 'Girdiğiniz şehir çok kısa.',
	'TOO_SHORT_MSN'					=> 'Girdiğiniz MSNM/WLM adı çok kısa.',
	'TOO_SHORT_NEW_PASSWORD'			=> 'Girdiğiniz şifre çok kısa.',
	'TOO_SHORT_OCCUPATION'			=> 'Girdiğiniz meslek çok kısa.',
	'TOO_SHORT_PASSWORD_CONFIRM'		=> 'Girdiğiniz şifre doğrulaması çok kısa.',
	'TOO_SHORT_USER_PASSWORD'		=> 'Girdiğiniz şifre çok kısa.',
	'TOO_SHORT_USERNAME'				=> 'Girdiğiniz kullanıcı adı çok kısa.',
	'TOO_SHORT_EMAIL'				=> 'Girdiğiniz e-posta adresi çok kısa.',
	'TOO_SHORT_EMAIL_CONFIRM'		=> 'Girdiğiniz e-posta adresi doğrulaması çok kısa.',
	'TOO_SHORT_WEBSITE'				=> 'Girdiğiniz web sitesi adresi çok kısa.',
	'TOO_SHORT_YIM'					=> 'Girdiğiniz Yahoo! Messenger adı çok kısa.',
	'TOO_SMALL'                  => 'Girdiğiniz değer çok küçük.',
   	'TOO_SMALL_MAX_RECIPIENTS'      => 'Girdiğiniz değer <strong>Her mesajda izin verilen en fazla alıcı sayısı</strong> ayarına göre çok küçük.',

	'TOPIC'				=> 'Başlık',
	'TOPICS'			=> 'Başlıklar',
	'TOPICS_UNAPPROVED'	=> 'Bu forumdaki en az bir başlık onaylanmadı.',
	'TOPIC_ICON'		=> 'Başlık simgesi',
	'TOPIC_LOCKED'		=> 'Bu başlık kilitlenmiştir mesajlarınızı düzenleyemez veya cevap gönderemezsiniz.',
	'TOPIC_LOCKED_SHORT'=> 'Başlık kilitlendi',
	'TOPIC_MOVED'		=> 'Taşınan başlık',
	'TOPIC_REVIEW'		=> 'Başlık incelemesi',
	'TOPIC_TITLE'		=> 'Konu Başlığı',
	'TOPIC_UNAPPROVED'	=> 'Bu başlık onaylanmadı',
	'TOTAL_ATTACHMENTS'	=> 'Eklenti(ler)',
	'TOTAL_LOG'			=> '1 eylem kaydı',
	'TOTAL_LOGS'		=> '%d eylem kaydı',
	'TOTAL_NO_PM'		=> 'Toplam 0 özel mesaj',
	'TOTAL_PM'			=> 'Toplam 1 özel mesaj',
	'TOTAL_PMS'			=> 'Toplam %d özel mesaj',
	'TOTAL_POSTS'		=> 'Toplam mesajlar',
	'TOTAL_POSTS_OTHER'	=> 'Toplam <strong>%d</strong> mesaj',
	'TOTAL_POSTS_ZERO'	=> 'Toplam <strong>0</strong> mesaj',
	'TOPIC_REPORTED'	=> 'Bu başlık bildirildi',
	'TOTAL_TOPICS_OTHER'=> 'Toplam <strong>%d</strong> başlık',
	'TOTAL_TOPICS_ZERO'	=> 'Toplam <strong>0</strong> başlık',
	'TOTAL_USERS_OTHER'	=> 'Toplam <strong>%d</strong> üye',
	'TOTAL_USERS_ZERO'	=> 'Toplam <strong>0</strong> üye',
	'TRACKED_PHP_ERROR'	=> 'İzlenen PHP hataları: %s',

	'UNABLE_GET_IMAGE_SIZE'	=> 'Resmin boyutlarını belirlemek mümkün olmadı. Lütfen girdiğiniz URL adresinin geçerli olup olmadığını kontrol edin.',
	'UNABLE_TO_DELIVER_FILE'=> 'Dosya teslim edilemiyor.',
	'UNKNOWN_BROWSER'		=> 'Bilinmeyen Tarayıcı',
	'UNMARK_ALL'			=> 'Tüm işaretleri kaldır',
	'UNREAD_MESSAGES'		=> 'Okunmayan Mesajlar',
	'UNREAD_PM'				=> '<strong>%d</strong> okunmayan mesaj',
	'UNREAD_PMS'			=> '<strong>%d</strong> okunmayan mesaj',
   	'UNREAD_POST'         => 'Okunmamış mesaj',
   	'UNREAD_POSTS'         => 'Okunmamış mesaj var',
	'UNWATCH_FORUM_CONFIRM'		=> 'Bu forumdan aboneliğinizi kaldırmak istediğinize emin misiniz?',
	'UNWATCH_FORUM_DETAILED'	=> '“%s” adlı forumdan aboneliğinizi kaldırmak istediğinize emin misiniz?',
	'UNWATCH_TOPIC_CONFIRM'		=> 'Bu başlıktan aboneliğinizi kaldırmak istediğinize emin misiniz?',
	'UNWATCH_TOPIC_DETAILED'	=> '“%s” konulu başlıktan aboneliğinizi kaldırmak istediğinize emin misiniz?',	
	'UNWATCHED_FORUMS'		=> 'Seçilen forumlara abone olmadınız.',
	'UNWATCHED_TOPICS'		=> 'Seçilen başlıklara abone olmadınız.',
	'UNWATCHED_FORUMS_TOPICS'   => 'Seçilen girdilere abone olmadınız.',
	'UPDATE'				=> 'Güncelle',
	'UPLOAD_IN_PROGRESS'	=> 'Yükleme şu anda devam ediyor.',
	'URL_REDIRECT'			=> 'Eğer tarayıcınız meta yönlendirmesini desteklemiyorsa %slütfen yönlenebilmek için BURAYI tıklayın%s.',
	'USERGROUPS'			=> 'Gruplar',
	'USERNAME'				=> 'Kullanıcı adı',
	'USERNAMES'				=> 'Kullanıcı adları',
	'USER_AVATAR'			=> 'Kullanıcı avatarı',
	'USER_CANNOT_READ'		=> 'Bu forumdaki mesajları okuyamazsınız.',
	'USER_POST'				=> '%d Mesaj',
	'USER_POSTS'			=> '%d Mesaj',
	'USERS'					=> 'Kullanıcılar',
	'USE_PERMISSIONS'		=> 'Kullanıcı’nın yetkilerini sına',
	'USER_NEW_PERMISSION_DISALLOWED'	=> 'Üzgünüz, ancak bu özelliği kullanmaya yetkili değilsiniz. Bu özelliği kullanabilmeniz için burada kayıtlı olmalısınız ve daha fazla katılım göstermelisiniz.',

	'VARIANT_DATE_SEPARATOR'	=> ' / ',	// Used in date format dropdown, eg: "Today, 13:37 / 01 Jan 2007, 13:37" ... to join a relative date with calendar date
	'VIEWED'					=> 'Görüntüleme',
	'VIEWING_FAQ'				=> 'SSS görüntüleniyor',
	'VIEWING_MEMBERS'			=> 'Üye detayları görüntüleniyor',
	'VIEWING_ONLINE'			=> 'Kimler’in çevrimiçi olduğu görüntüleniyor',
	'VIEWING_MCP'				=> 'Moderatör kontrol paneli görüntüleniyor',
	'VIEWING_MEMBER_PROFILE'	=> 'Üye profili görüntüleniyor',
	'VIEWING_PRIVATE_MESSAGES'	=> 'Özel mesajlar görüntüleniyor',
	'VIEWING_REGISTER'			=> 'Hesap kayıt ediliyor',
	'VIEWING_UCP'				=> 'Kullanıcı kontrol paneli görüntüleniyor',
	'VIEWS'						=> 'Görüntüleme',
	'VIEW_BOOKMARKS'			=> 'Sık kullanılanları görüntüle',
	'VIEW_FORUM_LOGS'			=> 'Kayıtları görüntüle',
	'VIEW_LATEST_POST'			=> 'Son mesajı görüntüle',
	'VIEW_NEWEST_POST'			=> 'İlk okunmamış mesajı görüntüle',
	'VIEW_NOTES'				=> 'Kullanıcı notlarını görüntüle',
	'VIEW_ONLINE_TIME'			=> 'son %d dakika öncesinden itibaren aktif olan kullanıcılar temel alınır',
	'VIEW_ONLINE_TIMES'			=> 'son %d dakika öncesinden itibaren aktif olan kullanıcılar temel alınır',
	'VIEW_TOPIC'				=> 'Başlığı görüntüle',
	'VIEW_TOPIC_ANNOUNCEMENT'	=> 'Duyuru: ',
	'VIEW_TOPIC_GLOBAL'			=> 'Global Duyuru: ',
	'VIEW_TOPIC_LOCKED'			=> 'Kilitlendi: ',
	'VIEW_TOPIC_LOGS'			=> 'Kayıtları görüntüle',
	'VIEW_TOPIC_MOVED'			=> 'Taşındı: ',
	'VIEW_TOPIC_POLL'			=> 'Anket: ',
	'VIEW_TOPIC_STICKY'			=> 'Sabit: ',
	'VISIT_WEBSITE'				=> 'Web sitesini ziyaret et',

	'WARNINGS'			=> 'Uyarılar',
	'WARN_USER'			=> 'Kullanıcıya uyarı ver',
	'WATCH_FORUM_CONFIRM'	=> 'Bu foruma abone olmak istediğinize emin misiniz?',
	'WATCH_FORUM_DETAILED'	=> '“%s” adlı foruma abone olmak istediğinize emin misiniz?',
	'WATCH_TOPIC_CONFIRM'	=> 'Bu başlığa abone olmak istediğinize emin misiniz?',
	'WATCH_TOPIC_DETAILED'	=> '“%s” konulu başlığa abone olmak istediğinize emin misiniz?',
	'WELCOME_SUBJECT'	=> '%s forumlarına hoşgeldiniz',
	'WEBSITE'			=> 'Web sitesi',
	'WHOIS'				=> 'Kimdir',
	'WHO_IS_ONLINE'		=> 'Kimler çevrimiçi',
	'WRONG_PASSWORD'	=> 'Hatalı bir şifre girdiniz.',

	'WRONG_DATA_COLOUR'			=> 'Girdiğiniz renk değeri geçersiz.',
	'WRONG_DATA_ICQ'			=> 'Girdiğiniz numara, geçersiz bir ICQ numarası.',
	'WRONG_DATA_JABBER'			=> 'Girilen ad, geçersiz bir Jabber hesap adı.',
	'WRONG_DATA_LANG'			=> 'Belirlediğiniz dil geçerli değil.',
	'WRONG_DATA_WEBSITE'		=> 'Web sitesi adresi, protokol dahilinde geçerli bir URL olmalıdır. Örneğin, http://www.ornek.com/.',
	'WROTE'						=> 'yazdı',

	'YEAR'				=> 'Yıl',
	'YEAR_MONTH_DAY'        => '(YYYY-AA-GG)',
	'YES'				=> 'Evet',
	'YIM'				=> 'YIM',
	'YOU_LAST_VISIT'	=> 'Son ziyaretiniz: %s',
	'YOU_NEW_PM'		=> 'Gelen kutunuzda bir yeni özel mesaj sizi bekliyor.',
	'YOU_NEW_PMS'		=> 'Gelen kutunuzda yeni özel mesajlar sizi bekliyor.',
	'YOU_NO_NEW_PM'		=> 'Sizi bekleyen yeni özel mesaj yok.',

	'datetime'			=> array(
		'TODAY'		=> 'Bugün',
		'TOMORROW'	=> 'Yarın',
		'YESTERDAY'	=> 'Dün',
		
		'AGO'		=> array(
			0		=> 'bir dakika önceden daha az',
			1		=> '%d dakika önce',
			2		=> '%d dakika önce',
			60		=> '1 saat önce',
		),

		'Sunday'	=> 'Pazar',
		'Monday'	=> 'Pazartesi',
		'Tuesday'	=> 'Salı',
		'Wednesday'	=> 'Çarşamba',
		'Thursday'	=> 'Perşembe',
		'Friday'	=> 'Cuma',
		'Saturday'	=> 'Cumartesi',

		'Sun'		=> 'Pzr',
		'Mon'		=> 'Pzt',
		'Tue'		=> 'Sal',
		'Wed'		=> 'Çrş',
		'Thu'		=> 'Prş',
		'Fri'		=> 'Cum',
		'Sat'		=> 'Cmt',

		'January'	=> 'Ocak',
		'February'	=> 'Şubat',
		'March'		=> 'Mart',
		'April'		=> 'Nisan',
		'May'		=> 'Mayıs',
		'June'		=> 'Haziran',
		'July'		=> 'Temmuz',
		'August'	=> 'Ağustos',
		'September' 	=> 'Eylül',
		'October'	=> 'Ekim',
		'November'	=> 'Kasım',
		'December'	=> 'Aralık',

		'Jan'		=> 'Oca',
		'Feb'		=> 'Şub',
		'Mar'		=> 'Mar',
		'Apr'		=> 'Nis',
		'May_short'	=> 'May',	// Short representation of "May". May_short used because in English the short and long date are the same for May.
		'Jun'		=> 'Haz',
		'Jul'		=> 'Tem',
		'Aug'		=> 'Ağu',
		'Sep'		=> 'Eyl',
		'Oct'		=> 'Eki',
		'Nov'		=> 'Kas',
		'Dec'		=> 'Ara',
	),

	'tz'				=> array(
		'-12'	=> 'UTC - 12 saat',
		'-11'	=> 'UTC - 11 saat',
		'-10'	=> 'UTC - 10 saat',
		'-9.5'	=> 'UTC - 9:30 saat',
		'-9'	=> 'UTC - 9 saat',
		'-8'	=> 'UTC - 8 saat',
		'-7'	=> 'UTC - 7 saat',
		'-6'	=> 'UTC - 6 saat',
		'-5'	=> 'UTC - 5 saat',
		'-4.5'   => 'UTC - 4:30 saat',
		'-4'	=> 'UTC - 4 saat',
		'-3.5'	=> 'UTC - 3:30 saat',
		'-3'	=> 'UTC - 3 saat',
		'-2'	=> 'UTC - 2 saat',
		'-1'	=> 'UTC - 1 saat',
		'0'		=> 'UTC',
		'1'		=> 'UTC + 1 saat',
		'2'		=> 'UTC + 2 saat',
		'3'		=> 'UTC + 3 saat',
		'3.5'	=> 'UTC + 3:30 saat',
		'4'		=> 'UTC + 4 saat',
		'4.5'	=> 'UTC + 4:30 saat',
		'5'		=> 'UTC + 5 saat',
		'5.5'	=> 'UTC + 5:30 saat',
		'5.75'	=> 'UTC + 5:45 saat',
		'6'		=> 'UTC + 6 saat',
		'6.5'	=> 'UTC + 6:30 saat',
		'7'		=> 'UTC + 7 saat',
		'8'		=> 'UTC + 8 saat',
		'8.75'	=> 'UTC + 8:45 saat',
		'9'		=> 'UTC + 9 saat',
		'9.5'	=> 'UTC + 9:30 saat',
		'10'	=> 'UTC + 10 saat',
		'10.5'	=> 'UTC + 10:30 saat',
		'11'	=> 'UTC + 11 saat',
		'11.5'	=> 'UTC + 11:30 saat',
		'12'	=> 'UTC + 12 saat',
		'12.75'	=> 'UTC + 12:45 saat',
		'13'	=> 'UTC + 13 saat',
		'14'	=> 'UTC + 14 saat',
		'dst'	=> '[ <abbr title="Gün Işığından Tasarruf Zamanı">GITZ</abbr> ]',
	),

	'tz_zones'	=> array(
		'-12'	=> '[UTC - 12, Y] Baker Adası Zamanı',
		'-11'	=> '[UTC - 11, X] Niue Zamanı, Samoa Standart Zamanı',
		'-10'	=> '[UTC - 10, W] Hawaii-Aleutian Standart Zamanı, Cook Adası Zamanı',
		'-9.5'	=> '[UTC - 9:30, V*] Marquesas Adaları Zamanı',
		'-9'	=> '[UTC - 9, V] Alaska Standart Zamanı, Gambier Adası Zamanı',
		'-8'	=> '[UTC - 8, U] Pasifik Standart Zamanı',
		'-7'	=> '[UTC - 7, T] Mountain Standart Zamanı',
		'-6'	=> '[UTC - 6, S] Merkez Standart Zamanı',
		'-5'	=> '[UTC - 5, R] Doğu Standart Zamanı',
		'-4.5'   => '[UTC - 4:30] Venezuella Standart Zamanı',
		'-4'	=> '[UTC - 4, Q] Atlantik Standart Zamanı',
		'-3.5'	=> '[UTC - 3:30, P*] Newfoundland Standart Zamanı',
		'-3'	=> '[UTC - 3, P] Amazon Standart Zamanı, Merkez Gronland Zamanı',
		'-2'	=> '[UTC - 2, O] Fernando de Noronha Zamanı, Güney Georgia &amp; Güney Sandwich Adaları Zamanı',
		'-1'	=> '[UTC - 1, N] Azores Standart Zamanı, Cape Verde Zamanı, Doğu Gronland Zamanı',
		'0'		=> '[UTC, Z] Batı Avrupa Zamanı, Greenwich Mean Zamanı',
		'1'		=> '[UTC + 1, A] Merkez Avrupa Zamanı, Batı Afrika Zamanı',
		'2'		=> '[UTC + 2, B] Doğu Avrupa Zamanı, Merkezi Afrika Zamanı',
		'3'		=> '[UTC + 3, C] Moskova Standart Zamanı, Doğu Afrika Zamanı',
		'3.5'	=> '[UTC + 3:30, C*] İran Standart Zamanı',
		'4'		=> '[UTC + 4, D] Gulf Standart Zamanı, Samara Standart Zamanı',
		'4.5'	=> '[UTC + 4:30, D*] Afganistan Zamanı',
		'5'		=> '[UTC + 5, E] Pakistan Standart Zamanı, Yekaterinburg Standart Zamanı',
		'5.5'	=> '[UTC + 5:30, E*] Hindistan Standart Zamanı, Sri Lanka Zamanı',
		'5.75'	=> '[UTC + 5:45, E&Dagger;] Nepal Zamanı',
		'6'		=> '[UTC + 6, F] Bangladeş Zamanı, Bhutan Zamanı, Novosibirsk Standart Zamanı',
		'6.5'	=> '[UTC + 6:30, F*] Cocos Adaları Zamanı, Myanmar Zamanı',
		'7'		=> '[UTC + 7, G] Indochina Zamanı, Krasnoyarsk Standart Zamanı',
		'8'		=> '[UTC + 8, H] Çin Standart Zamanı, Avustralya Batı Standart Zamanı, Irkutsk Standart Zamanı',
		'8.75'	=> '[UTC + 8:45, H&Dagger;] Güneydoğu Batı Avustralya Standart Zamanı',
		'9'		=> '[UTC + 9, I] Japonya Standart Zamanı, Kore Standart Zamanı, Chita Standart Zamanı',
		'9.5'	=> '[UTC + 9:30, I*] Avustralya Merkez Standart Zamanı',
		'10'	=> '[UTC + 10, K] Avustralya Doğu Standart Zamanı, Vladivostok Standart Zamanı',
		'10.5'	=> '[UTC + 10:30, K*] Lord Howe Standart Zamanı',
		'11'	=> '[UTC + 11, L] Solomon Adası Zamanı, Magadan Standart Zamanı',
		'11.5'	=> '[UTC + 11:30, L*] Norfolk Adası Zamanı',
		'12'	=> '[UTC + 12, M] Yeni Zelanda Zamanı, Fiji Zamanı, Kamchatka Standart Zamanı',
		'12.75'	=> '[UTC + 12:45, M&Dagger;] Chatham Adaları Zamanı',
		'13'	=> '[UTC + 13, M*] Tonga Zamanı, Phoenix Adaları Zamanı',
		'14'	=> '[UTC + 14, M&dagger;] Line Adası Zamanı',
	),

	// The value is only an example and will get replaced by the current time on view
	'dateformats'	=> array(
 		'd M Y, H:i'			=> '01 Oca 2007, 13:37',
 		'd M Y H:i'				=> '01 Oca 2007 13:37',
 		'M jS, \'y, H:i'		=> 'Oca 1., \'07, 13:37',
 		'D M d, Y g:i a'		=> 'Pzt Oca 01, 2007 1:37 pm',
 		'F jS, Y, g:i a'		=> 'Ocak 1., 2007, 1:37 pm',
 		'|d M Y|, H:i'			=> 'Bugün, 13:37 / 01 Oca 2007, 13:37',
 		'|F jS, Y|, g:i a'		=> 'Bugün, 1:37 pm / Ocak 1., 2007, 1:37 pm'
	),

	// The default dateformat which will be used on new installs in this language
	// Translators should change this if a the usual date format is different
	'default_dateformat'	=> 'D M d, Y g:i a', // Mon Jan 01, 2007 1:37 pm

));

?>